@@ -2,17 +2,25 @@ package TestML::Setup;
 
 use TestML::Base;
 
-use YAML::XS;
-use IO::All;
-use Template::Toolkit::Simple;
+use TestML();
+BEGIN {
+    for (qw( YAML::XS IO::All Template::Toolkit::Simple )) {
+        eval "use $_; 1" or die "TestML::Setup requires $_:\n$@";
+    }
+}
 use File::Basename;
 use Cwd 'abs_path';
+use Exporter 'import';
+
+our @EXPORT = qw( setup );
 
 use constant DEFAULT_TESTML_CONF => './t/testml.yaml';
 
 sub setup {
-    my ($self, $testml_conf) = @_;
-    $testml_conf ||= DEFAULT_TESTML_CONF;
+    my ($testml_conf) = @_;
+    $testml_conf ||=
+        $ARGV[0] ||
+        DEFAULT_TESTML_CONF;
     die "TestML conf file '$testml_conf' not found"
       unless -f $testml_conf;
     die "TestML conf file must be .yaml"
@@ -41,7 +49,7 @@ sub setup {
         my $s = "$source/$file";
         my $t = "$target/$file";
         if (not -f $t or io($s)->all ne io($t)->all) {
-            print "Copying ${\$self->rel($s)} to ${\$self->rel($t)}\n";
+            print "Copying ${\ relative_path($s)} to ${\ relative_path($t)}\n";
             io($t)->print(io($s)->all);
         }
         if ($template) {
@@ -49,24 +57,42 @@ sub setup {
             $test = $conf->{test_file_prefix} . $test
                 if $conf->{test_file_prefix};
             $test = abs_path "$tests/$test";
+            my ($volume, $directories, $file) =
+                File::Spec->splitpath(relative_path($t, $base));
+            my $path = [
+                grep $_, File::Spec->splitdir($directories), $file
+            ];
             my $hash = {
-                file => $self->rel($t, $base),
+                testml_setup_comment => testml_setup_comment($testml_conf),
+                file => relative_path($t, $base),
+                path => $path,
             };
             my $code = tt->data($hash)->render(\$template);
             if (not -f $test or $code ne io($test)->all) {
                 my $action = -f $test ? 'Updating' : 'Creating';
-                print "$action test file '${\$self->rel($test)}'\n";
+                print "$action test file '${\ relative_path($test)}'\n";
                 io($test)->print($code);
             }
         }
     }
 }
 
-sub rel {
-    my ($self, $path, $base) = @_;
+sub relative_path {
+    my ($path, $base) = @_;
     $base ||= '.';
     $base = abs_path($base);
     File::Spec->abs2rel($path, $base);
 }
 
+sub testml_setup_comment {
+    my ($testml_conf) = @_;
+    <<"...";
+# DO NOT EDIT
+#
+# This file was generated by TestML::Setup ($TestML::VERSION)
+#
+#   > perl -MTestML::Setup -e setup $testml_conf
+...
+}
+
 1;
